# YADA

[![Build Status](https://travis-ci.com/apetresc/yada.svg?branch=master)](https://travis-ci.com/apetresc/yada)
[![PyPI version](https://badge.fury.io/py/yada.svg)](https://badge.fury.io/py/yada)

Yet Another Dotfile Aggregator
